%global fz_rc	rc1

Name:           filezilla
Version:        3.25.0
Release:        0.%{?fz_rc}%{?dist}
#Release:        1%{?dist}
Summary:        FTP, FTPS and SFTP client

Group:          Applications/Internet
License:        GPLv2+
URL:            http://filezilla-project.org/
Source0:        http://download.filezilla-project.org/FileZilla_%{version}%{?fz_rc:-%{?fz_rc}}_src.tar.bz2
#Patch0:         filezilla-wxstring.patch
#Patch1:         filezilla-gtk.patch
#Patch2:         filezilla-3.24.1-desktop.patch

## Needed if autogen.sh is invoked
#BuildRequires:  automake, autoconf, libtool
## 
## Needed if test program is build
BuildRequires:  cppunit-devel >= 1.10.2
##
%if 0%{?fedora}
BuildRequires:  libappstream-glib
%endif
BuildRequires:  desktop-file-utils
BuildRequires:  xdg-utils
Requires:       xdg-utils

BuildRequires:  dbus-devel
BuildRequires:  gettext
BuildRequires:  gnutls-devel >= 2.8.3
BuildRequires:  libidn-devel
%if 0%{?fedora} >= 24
# filezilla requires long long which is default enabled by 1.7
BuildRequires:  pugixml-devel >= 1.7
%else
Provides: bundled(pugixml)
%endif
BuildRequires:  sqlite-devel
BuildRequires:  wxGTK3-devel >= 3.0.1
BuildRequires:  libappstream-glib
BuildRequires:  libfilezilla-devel
BuildRequires:  nettle-devel

%description
FileZilla is a FTP, FTPS and SFTP client for Linux with a lot of features.
- Supports FTP, FTP over SSL/TLS (FTPS) and SSH File Transfer Protocol (SFTP)
- Cross-platform
- Available in many languages
- Supports resume and transfer of large files >4GB
- Easy to use Site Manager and transfer queue
- Drag & drop support
- Speed limits
- Filename filters
- Network configuration wizard 


%prep
%setup -q -n %{name}-%{version}%{?fz_rc:-%{?fz_rc}}

#%%patch0 -p0
#%%patch1 -p2
#%patch2 -p0

# Run autotools if needed
# sh autoconf


%build
# for wxGTK3 - needed to find wxrc
export WXRC=%{_bindir}/wxrc-3.0
%configure \
  --disable-static \
  --enable-locales \
  --disable-manualupdatecheck \
%if 0%{?fedora} >= 24
  --with-pugixml=system \
%else
  --with-pugixml=builtin \
%endif
  --with-wx-config=wx-config-3.0 \
  --with-dbus \
  --enable-gnutlssystemciphers \
  --disable-autoupdatecheck 

## Do not use --enable-buildtype=official 
## that option enables the "check for updates" dialog to download
## new binaries from the official website.

# Remove the timyxml internal static lib to configure will not fails
#rm -rf src/tinyxml/

make %{?_smp_mflags}


%install
make install DESTDIR=$RPM_BUILD_ROOT INSTALL="install -p -c"

# Update the screenshot shown in the software center
#
# NOTE: It would be *awesome* if this file was pushed upstream.
#
# See http://people.freedesktop.org/~hughsient/appdata/#screenshots for more details.
#
appstream-util replace-screenshots $RPM_BUILD_ROOT%{_datadir}/appdata/filezilla.appdata.xml \
  https://raw.githubusercontent.com/hughsie/fedora-appstream/master/screenshots-extra/filezilla/a.png 

for i in 16x16 32x32 48x48 ; do
  mkdir -p $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/${i}/apps
  ln -sf ../../../../%{name}/resources/${i}/%{name}.png \
    $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/${i}/apps/%{name}.png
done

rm -rf $RPM_BUILD_ROOT%{_datadir}/pixmaps

desktop-file-install \
  --delete-original \
  --dir ${RPM_BUILD_ROOT}%{_datadir}/applications \
  ${RPM_BUILD_ROOT}%{_datadir}/applications/%{name}.desktop

%if 0%{?fedora}
appstream-util validate-relax --nonet \
  $RPM_BUILD_ROOT/%{_datadir}/appdata/*.appdata.xml
%endif

#Create directory for system wide settings
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/%{name}
#Ghost configuration file
touch $RPM_BUILD_ROOT%{_sysconfdir}/%{name}/fzdefaults.xml
#This is not the usual docdir
rm -rf $RPM_BUILD_ROOT%{_datadir}/%{name}/docs


%find_lang %{name}

%check
make check


%post
touch --no-create %{_datadir}/icons/hicolor
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor
fi || :

%postun
touch --no-create %{_datadir}/icons/hicolor
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor
fi || :


%files -f %{name}.lang
%doc AUTHORS ChangeLog COPYING NEWS
%doc docs/fzdefaults.xml.example
%dir %{_sysconfdir}/%{name}
%ghost %{_sysconfdir}/%{name}/fzdefaults.xml
%{_bindir}/*
%{_datadir}/filezilla/
%{_datadir}/appdata/filezilla.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/filezilla.svg
%{_mandir}/man1/*
%{_mandir}/man5/*


%changelog
* Mon Mar 06 2017 Jon Ciesla <limburgher@gmail.com> - 3.25.0-0.rc1
- Latest upstream.

* Mon Feb 27 2017 Jon Ciesla <limburgher@gmail.com> - 3.25.0-0.beta1
- Latest upstream.

* Wed Feb 22 2017 Jon Ciesla <limburgher@gmail.com> - 3.24.1-1
- Latest upstream.

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.24.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sat Jan 14 2017 Jon Ciesla <limburgher@gmail.com> - 3.24.0-1
- Latest upstream.

* Mon Jan 09 2017 Jon Ciesla <limburgher@gmail.com> - 3.24.0-0.rc1
- Latest upstream.

* Tue Dec 06 2016 Jon Ciesla <limburgher@gmail.com> - 3.23.0.2-1
- Latest upstream.

* Tue Dec 06 2016 Jon Ciesla <limburgher@gmail.com> - 3.23.0.1-1
- Latest upstream.

* Thu Nov 03 2016 Jon Ciesla <limburgher@gmail.com> - 3.22.2.2-1
- Latest upstream.

* Tue Nov 01 2016 Jon Ciesla <limburgher@gmail.com> - 3.22.2-1
- Latest upstream.

* Mon Oct 31 2016 Jon Ciesla <limburgher@gmail.com> - 3.22.2-0.rc2
- Latest upstream.

* Wed Oct 26 2016 Jon Ciesla <limburgher@gmail.com> - 3.22.2-0.rc1
- Latest upstream.

* Tue Oct 04 2016 Jon Ciesla <limburgher@gmail.com> - 3.22.1-1
- Latest upstream.

* Mon Oct 03 2016 Jon Ciesla <limburgher@gmail.com> - 3.22.0-1
- Latest upstream.

* Mon Sep 26 2016 Jon Ciesla <limburgher@gmail.com> - 3.22.0-0.rc1
- Latest upstream.

* Tue Aug 23 2016 Jon Ciesla <limburgher@gmail.com> - 3.21.0-1
- Latest upstream.

* Thu Aug 04 2016 Jon Ciesla <limburgher@gmail.com> - 3.20.1-1
- Latest upstream.

* Thu Jul 28 2016 Jon Ciesla <limburgher@gmail.com> - 3.20.0-1
- Latest upstream.

* Thu Jul 21 2016 Jon Ciesla <limburgher@gmail.com> - 3.20.0-0.rc1
- Latest upstream.

* Fri Jul 08 2016 Jon Ciesla <limburgher@gmail.com> - 3.19.0-2
- Patch for gtk bug, BZ 1351308

* Mon Jun 27 2016 Jon Ciesla <limburgher@gmail.com> - 3.19.0-1
- Latest upstream.

* Tue Jun 21 2016 Jon Ciesla <limburgher@gmail.com> - 3.19.0-0.rc1
- Latest upstream.

* Mon May 30 2016 Jon Ciesla <limburgher@gmail.com> - 3.18.0-1
- Latest upstream.

* Sun May 22 2016 Jon Ciesla <limburgher@gmail.com> - 3.18.0-0.rc1
- Latest upstream.

* Mon May 09 2016 Jon Ciesla <limburgher@gmail.com> - 3.17.0.1-1
- Latest upstream, BZ 1334341.
- Patch for wxString conversion bug.

* Mon Apr 25 2016 Jon Ciesla <limburgher@gmail.com> - 3.17.0-1
- Latest upstream.

* Tue Mar 22 2016 Jon Ciesla <limburgher@gmail.com> - 3.16.1-1
- Latest upstream.

* Tue Mar 15 2016 Jon Ciesla <limburgher@gmail.com> - 3.16.0-1
- Latest upstream, now uses libfilezilla.

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.14.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Oct 23 2015 Nicolas Chauvet <kwizart@gmail.com> - 3.14.1-2
- Use system pugixml by f24
- Explicitely enable dbus
- Enable system ciphers with upstreamed patch - rhbz#1179288

* Fri Oct 16 2015 Jon Ciesla <limburgher@gmail.com> - 3.14.1-1
- Update to 3.14.1.
- System ciphers patch upstremed.

* Tue Sep 22 2015 Jon Ciesla <limburgher@gmail.com> - 3.14.0-1
- Update to 3.14.0.

* Tue Sep 01 2015 Nicolas Chauvet <kwizart@gmail.com> - 3.13.1-1
- Update to 3.13.1
- Switch from builtin tinyxml to builtin pugixml

* Mon Aug 03 2015 Nicolas Chauvet <kwizart@gmail.com> - 3.12.0.2-2
- Update to system certificate for gnutls - rhbz#1179288

* Wed Jul 22 2015 Nicolas Chauvet <kwizart@gmail.com> - 3.12.0.2-1
- Update to 3.12.0.2

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.11.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed Jun 03 2015 Jon Ciesla <limburgher@gmail.com> - 3.11.0.2-1
- Update to 3.11.0.2.

* Tue May 26 2015 Jon Ciesla <limburgher@gmail.com> - 3.11.0.1-1
- Update to 3.11.0.1.

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 3.10.3-2
- Rebuilt for GCC 5 C++11 ABI change

* Thu Apr 02 2015 Nicolas Chauvet <kwizart@gmail.com> - 3.10.3-1
- Update to 3.10.3

* Mon Mar 30 2015 Richard Hughes <rhughes@redhat.com> - 3.10.3-0.3
- Use better AppData screenshots

* Tue Mar 17 2015 Nicolas Chauvet <kwizart@gmail.com> - 3.10.3-0.2
- Update to 3.10.3-beta2

* Thu Mar 12 2015 Nicolas Chauvet <kwizart@gmail.com> - 3.10.2-1
- Update to 3.10.2

* Wed Feb 25 2015 Nicolas Chauvet <kwizart@gmail.com> - 3.10.2-0.1
- Update to 3.10.2-rc2

* Mon Jan 19 2015 Nicolas Chauvet <kwizart@gmail.com> - 3.10.0.2-1
- Update to 3.10.0.2

* Wed Jan 07 2015 Nicolas Chauvet <kwizart@gmail.com> - 3.10.0-1
- Update to 3.10.0
- Add appdata support for fedora

* Sun Jan 04 2015 Nicolas Chauvet <kwizart@gmail.com> - 3.10.0-0.1_rc2
- Update to 3.10.0-rc2

* Wed Nov 12 2014 Nicolas Chauvet <kwizart@gmail.com> - 3.9.0.6-2
- Rebuilt with fixed wxGTK3 - rhbz#1124402

* Mon Oct 20 2014 kwizart <kwizart@gmail.com> - 3.9.0.6-1
- Update to 3.9.0.6

* Fri Oct 03 2014 kwizart <kwizart@gmail.com> - 3.9.0.5-1
- Update to 3.9.0.5

* Fri Aug 29 2014 Nicolas Chauvet <kwizart@gmail.com> - 3.9.0.3-1
- Update to 3.9.0.3

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.9.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Tue Jul 29 2014 Nicolas Chauvet <kwizart@gmail.com> - 3.9.0.1-1
- Update to 3.9.0.1

* Thu Jul 10 2014 Nicolas Chauvet <kwizart@gmail.com> - 3.9.0-0.1_rc2
- Update to 3.9.0 rc2
- Switch to wxGTK3 (use wx-config-3.0)

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.8.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon Jun 02 2014 Nicolas Chauvet <kwizart@gmail.com> - 3.8.1-1
- Update to 3.8.1

* Tue Apr 01 2014 Nicolas Chauvet <kwizart@gmail.com> - 3.8.0-1
- Update to 3.8.0

* Wed Feb 12 2014 Nicolas Chauvet <kwizart@gmail.com> - 3.7.4.1-1
- Update to 3.7.4.1

* Wed Feb 12 2014 Nicolas Chauvet <kwizart@gmail.com> - 3.7.4-1
- Update to 3.7.4

* Mon Aug 12 2013 Nicolas Chauvet <kwizart@gmail.com> - 3.7.3-1
- Update to 3.7.3 - Security fixes
 CVE-2013-4206, CVE-2013-4207, CVE-2013-4208, CVE-2013-4852

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.7.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Jun 21 2013 Nicolas Chauvet <kwizart@gmail.com> - 3.7.1-1
- Update to 3.7.1

* Mon May 27 2013 Nicolas Chauvet <kwizart@gmail.com> - 3.7.0.2-1
- Update to 3.7.0.2

* Mon May 13 2013 Nicolas Chauvet <kwizart@gmail.com> - 3.7.0.1-1
- Update to 3.7.0.1

* Tue Feb 12 2013 Jon Ciesla <limburgher@gmail.com> - 3.6.0.2-2
- Drop desktop vendor tag.

* Mon Dec 03 2012 Nicolas Chauvet <kwizart@gmail.com> - 3.6.0.2-1
- Update to 3.6.0.2

* Fri Nov 02 2012 Nicolas Chauvet <kwizart@gmail.com> - 3.6.0-1_rc1
- Update to 3.6.0-rc1

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.5.3-1.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Jan 11 2012 Nicolas Chauvet <kwizart@gmail.com> - 3.5.3-1
- Update to 3.5.3

* Tue Dec 06 2011 Adam Jackson <ajax@redhat.com> - 3.5.2-1.1
- Rebuild for new libpng

* Sun Nov 27 2011 Nicolas Chauvet <kwizart@gmail.com> - 3.5.2-1
- Update to 3.5.2

* Wed Aug 31 2011 Nicolas Chauvet <kwizart@gmail.com> - 3.5.1-1
- Update to 3.5.1

* Wed May 25 2011 Nicolas Chauvet <kwizart@gmail.com> - 3.5.0-1
- Update to 3.5.0 (final)

* Tue May 10 2011 Nicolas Chauvet <kwizart@gmail.com> - 3.5.0-0.1_rc1
- Update to 3.5.0-rc1

* Mon Mar 28 2011 Nicolas Chauvet <kwizart@gmail.com> - 3.4.0-1
- Update to 3.4.0 (final)

* Sat Mar 26 2011 Nicolas Chauvet <kwizart@gmail.com> - 3.4.0-0.1_rc1
- Update to 3.4.0-rc1

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.3.5.1-2.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Nov 29 2010 Nicolas Chauvet <kwizart@gmail.com> - 3.3.5.1-2
- Keep docs in the appropriate place
- Improve summary

* Sun Nov 28 2010 Nicolas Chauvet <kwizart@gmail.com> - 3.3.5.1-1
- Update to 3.3.5.1

* Thu Nov 18 2010 Nicolas Chauvet <kwizart@gmail.com> - 3.3.5-0.1
- Update to 3.3.5
- Add RPM registration for system wide settings

* Sun Aug 22 2010 Nicolas Chauvet <kwizart@gmail.com> - 3.3.4.1-1
- Update to 3.3.4.1

* Fri Aug 13 2010 Nicolas Chauvet <kwizart@gmail.com> - 3.3.4-1
- Update to 3.3.4

* Wed Jul 14 2010 Dan Horák <dan@danny.cz> - 3.3.3-1.1
- rebuilt against wxGTK-2.8.11-2

* Mon Jun 21 2010 Nicolas Chauvet <kwizart@gmail.com> - 3.3.3-1
- Update to 3.3.3

* Sat Mar 27 2010 Nicolas Chauvet <kwizart@fedoraproject.org> - 3.3.2.1-1
- Update to 3.3.2.1

* Sun Feb 21 2010 Nicolas Chauvet <kwizart@fedoraproject.org> - 3.3.2-1
- Update to 3.3.2

* Sun Jan 10 2010 Nicolas Chauvet <kwizart@fedoraproject.org> - 3.3.1-1
- Update to 3.3.1

* Sun Jan  3 2010 Nicolas Chauvet <kwizart@fedoraproject.org> - 3.3.1-0.1_rc1
- Update to 3.3.1-rc1
- Add Requires xdg-utils

* Sun Nov 22 2009 Nicolas Chauvet <kwizart@fedoraproject.org> - 3.3.0.1-1
- Update to 3.3.0.1

* Wed Nov 11 2009 kwizart < kwizart at gmail.com > - 3.3.0-1
- Update to 3.3.0

* Wed Nov  4 2009 kwizart < kwizart at gmail.com > - 3.3.0-0.3_rc1
- Update to 3.3.0-rc1

* Mon Nov  2 2009 kwizart < kwizart at gmail.com > - 3.3.0-0.2_beta2
- Update to 3.3.0-beta2

* Tue Oct 27 2009 kwizart < kwizart at gmail.com > - 3.3.0-0.1_beta1
- Update to 3.3.0-beta1

* Fri Oct 16 2009 kwizart < kwizart at gmail.com > - 3.2.8.1-1
- Update to 3.2.8.1

* Wed Oct  7 2009 kwizart < kwizart at gmail.com > - 3.2.8-1
- Update to 3.2.8

* Sat Oct  3 2009 kwizart < kwizart at gmail.com > - 3.2.8-0.1-rc1
- Update to 3.2.8-rc1

* Sat Aug 29 2009 kwizart < kwizart at gmail.com > - 3.2.7.1-1
- Update to 3.2.7.1

* Thu Aug 20 2009 kwizart < kwizart at gmail.com > - 3.2.7-2
- Update to 3.2.7
- Backport Fix for ipaddress.cpp at make check

* Mon Aug  3 2009 kwizart < kwizart at gmail.com > - 3.2.7-0.1_rc1
- Update to 3.2.7-rc1

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2.6.1-1.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Jul  6 2009 kwizart < kwizart at gmail.com > - 3.2.6-1
- Update to 3.2.6.1

* Mon Jun 29 2009 kwizart < kwizart at gmail.com > - 3.2.6-1
- Update to 3.2.6 stable

* Tue Jun 23 2009 kwizart < kwizart at gmail.com > - 3.2.6-0.1_rc1
- Update to 3.2.6-rc1

* Tue Jun 16 2009 kwizart < kwizart at gmail.com > - 3.2.5-1
- Update to 3.2.5 stable

* Thu Jun 11 2009 kwizart < kwizart at gmail.com > - 3.2.5-0.1_rc1
- Update to 3.2.5-rc1

* Tue Apr 28 2009 kwizart < kwizart at gmail.com > - 3.2.4.1-1
- Update to 3.2.4.1

* Tue Apr 21 2009 kwizart < kwizart at gmail.com > - 3.2.4-1
- Update to 3.2.4

* Thu Apr  2 2009 kwizart < kwizart at gmail.com > - 3.2.3.1-1
- Update to 3.2.3.1 stable

* Mon Mar 23 2009 kwizart < kwizart at gmail.com > - 3.2.3-1
- Update to 3.2.3 stable

* Mon Mar 16 2009 kwizart < kwizart at gmail.com > - 3.2.3-0.1_rc1
- Update to 3.2.3-rc1

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2.2.1-1.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Feb 23 2009 kwizart < kwizart at gmail.com > - 3.2.2.1-1
- Update to 3.2.2.1 stable

* Fri Feb 20 2009 kwizart < kwizart at gmail.com > - 3.2.2-1
- Update to 3.2.2 stable

* Tue Feb 10 2009 kwizart < kwizart at gmail.com > - 3.2.1-1
- Update to 3.2.1 stable

* Tue Feb  3 2009 kwizart < kwizart at gmail.com > - 3.2.1-0.1_rc1
- Update to 3.2.1-rc1

* Thu Jan  8 2009 kwizart < kwizart at gmail.com > - 3.2.0-1
- Update to 3.2.0 stable

* Tue Jan  6 2009 kwizart < kwizart at gmail.com > - 3.2.0-0.1_rc2
- Update to 3.2.0-rc2
- Add BR dbus-devel - Needs a fix for gnome-session
  see http://bugzilla.gnome.org/show_bug.cgi?id=559469

* Thu Dec  4 2008 kwizart < kwizart at gmail.com > - 3.1.6-1
- Update to 3.1.6

* Tue Nov 18 2008 kwizart < kwizart at gmail.com > - 3.1.5.1-1
- Update to 3.1.5.1

* Fri Oct 24 2008 kwizart < kwizart at gmail.com > - 3.1.5-1
- Update to 3.1.5

* Fri Oct 17 2008 kwizart < kwizart at gmail.com > - 3.1.4.1-1
- Update to 3.1.4.1

* Sat Oct 11 2008 kwizart < kwizart at gmail.com > - 3.1.4-0.1.rc1
- Update to 3.1.4-rc1

* Mon Sep 29 2008 kwizart < kwizart at gmail.com > - 3.1.3.1-1
- Update to 3.1.3.1

* Tue Sep 23 2008 kwizart < kwizart at gmail.com > - 3.1.3-1
- Update to 3.1.3

* Mon Sep  1 2008 kwizart < kwizart at gmail.com > - 3.1.2-1
- Update to 3.1.2

* Thu Aug 14 2008 kwizart < kwizart at gmail.com > - 3.1.1.1-1
- Update to 3.1.1.1

* Mon Aug 11 2008 kwizart < kwizart at gmail.com > - 3.1.1-1
- Update to 3.1.1

* Fri Jul 25 2008 kwizart < kwizart at gmail.com > - 3.1.0.1-1
- Update to 3.1.0.1 - Security update

* Mon Jul 14 2008 kwizart < kwizart at gmail.com > - 3.1.0-0.1.beta2
- Update to 3.1.0-beta2

* Tue Jul  8 2008 kwizart < kwizart at gmail.com > - 3.0.11.1-1
- Update to 3.0.11.1

* Mon Jun 16 2008 kwizart < kwizart at gmail.com > - 3.0.11-1
- Update to 3.0.11
- Create patch for a shared tinyxml.
- Add support for hicolor icons.

* Wed May 21 2008 kwizart < kwizart at gmail.com > - 3.0.10-1
- Update to 3.0.10

* Wed May  7 2008 kwizart < kwizart at gmail.com > - 3.0.9.3-1
- Update to 3.0.9.3

* Sat Apr 19 2008 kwizart < kwizart at gmail.com > - 3.0.9.2-1
- Update to 3.0.9.2

* Mon Apr  7 2008 kwizart < kwizart at gmail.com > - 3.0.9.1-1
- Update to 3.0.9.1

* Mon Apr  7 2008 kwizart < kwizart at gmail.com > - 3.0.9-1
- Update to 3.0.9

* Mon Mar 31 2008 kwizart < kwizart at gmail.com > - 3.0.9-0.1.rc1
- Update to 3.0.9-rc1

* Tue Mar 18 2008 kwizart < kwizart at gmail.com > - 3.0.8.1-1
- Update to 3.0.8.1
- Add patch for make check

* Fri Mar 14 2008 kwizart < kwizart at gmail.com > - 3.0.8-1
- Update to 3.0.8

* Fri Mar  7 2008 kwizart < kwizart at gmail.com > - 3.0.8-0.1.rc1
- Update to 3.0.8-rc1

* Wed Feb 20 2008 kwizart < kwizart at gmail.com > - 3.0.7.1-1
- Update to 3.0.7.1

* Thu Jan 31 2008 kwizart < kwizart at gmail.com > - 3.0.6-1
- Update to 3.0.6

* Thu Jan 17 2008 kwizart < kwizart at gmail.com > - 3.0.5.2-1
- Update to 3.0.5.2
- Drop update desktop file in post and postun

* Thu Jan 10 2008 kwizart < kwizart at gmail.com > - 3.0.4-1
- Update to 3.0.4

* Wed Nov  7 2007 kwizart < kwizart at gmail.com > - 3.0.3-1
- Update to 3.0.3

* Fri Oct 19 2007 kwizart < kwizart at gmail.com > - 3.0.2.1-1
- Update to 3.0.2.1

* Sat Sep 22 2007 kwizart < kwizart at gmail.com > - 3.0.1-1
- Update to 3.0.1

* Sun Sep  9 2007 kwizart < kwizart at gmail.com > - 3.0.0-1
- Update to 3.0.0 (final)
- Add vendor field for .desktop

* Mon Sep  3 2007 kwizart < kwizart at gmail.com > - 3.0.0-0.3.rc3
- Update to 3.0.0rc3
- Add BR gawk
- Improve description/summary
- Removed dual listed doc file

* Mon Aug 27 2007 kwizart < kwizart at gmail.com > - 3.0.0-0.2.rc2
- Update to 3.0.0-rc2
- Upstream now install their own desktop file and pixmap

* Mon Aug 13 2007 kwizart < kwizart at gmail.com > - 3.0.0-0.2.rc1
- Update to 3.0.0-rc1
- Enable make check

* Fri Jul 27 2007 kwizart < kwizart at gmail.com > - 3.0.0-0.1.beta11
- Update to beta11

* Tue Jun  5 2007 kwizart < kwizart at gmail.com > - 3.0.0-0.1.beta10
- Update to beta10

* Sat May 26 2007 kwizart < kwizart at gmail.com > - 3.0.0-0.1.beta8
- Update to beta8

* Tue Mar 13 2007 kwizart < kwizart at gmail.com > - 3.0.0-0.1.beta7
- Update to beta7

* Tue Mar 13 2007 kwizart < kwizart at gmail.com > - 3.0.0-0.1.beta6
- Initial package.
